@@ -1,12 +1,13 @@
 import abc
 
+import six
 
+
+@six.add_metaclass(abc.ABCMeta)
 class FormatterBase(object):
-    """Base class for example plugin used in the tutoral.
+    """Base class for example plugin used in the tutorial.
     """
 
-    __metaclass__ = abc.ABCMeta
-
     def __init__(self, max_width=60):
         self.max_width = max_width
 
